@@ -1,7 +1,7 @@
 #ifndef __XS_PARSE_KEYWORD_H__
 #define __XS_PARSE_KEYWORD_H__
 
-#define XSPARSEKEYWORD_ABI_VERSION 1
+#define XSPARSEKEYWORD_ABI_VERSION 2
 
 struct XSParseKeywordPieceType;
 struct XSParseKeywordPieceType {
@@ -179,7 +179,7 @@ struct XSParseKeywordHooks {
   /* These are alternatives; the first one defined is used */
   int (*parse)(pTHX_ OP **opp, void *hookdata);
   int (*build)(pTHX_ OP **out, XSParseKeywordPiece *args[], size_t nargs, void *hookdata);
-  int (*build1)(pTHX_ OP **out, XSParseKeywordPiece arg0, void *hookdata);
+  int (*build1)(pTHX_ OP **out, XSParseKeywordPiece *arg0, void *hookdata);
 };
 
 static void (*register_xs_parse_keyword_func)(pTHX_ const char *kwname, const struct XSParseKeywordHooks *hooks, void *hookdata);
@@ -203,19 +203,18 @@ static void S_boot_xs_parse_keyword(pTHX_ double ver) {
   if(!svp)
     croak("XS::Parse::Keyword ABI minimum version missing");
   int abi_ver = SvIV(*svp);
-
   if(abi_ver > XSPARSEKEYWORD_ABI_VERSION)
     croak("XS::Parse::Keyword ABI version mismatch - library supports >= %d, compiled for %d",
         abi_ver, XSPARSEKEYWORD_ABI_VERSION);
 
   svp = hv_fetchs(PL_modglobal, "XS::Parse::Keyword/ABIVERSION_MAX", 0);
   abi_ver = SvIV(*svp);
-  if(abi_ver < 1)
-    croak("XS::Parse::Keyword ABI version mismatch - runtime requires at least version 1, library only supports %d",
-        abi_ver);
+  if(abi_ver < XSPARSEKEYWORD_ABI_VERSION)
+    croak("XS::Parse::Keyword ABI version mismatch - library supports <= %d, compiled for %d",
+        abi_ver, XSPARSEKEYWORD_ABI_VERSION);
 
   register_xs_parse_keyword_func = INT2PTR(void (*)(pTHX_ const char *, const struct XSParseKeywordHooks *, void *),
-      SvUV(*hv_fetchs(PL_modglobal, "XS::Parse::Keyword/register()@1", 0)));
+      SvUV(*hv_fetchs(PL_modglobal, "XS::Parse::Keyword/register()@2", 0)));
 }
 
 #endif
