@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2021 -- leonerd@leonerd.org.uk
 
-package XS::Parse::Keyword 0.12;
+package XS::Parse::Keyword 0.13;
 
 use v5.14;
 use warnings;
@@ -149,7 +149,7 @@ This alternative is somewhat less generic and powerful than providing C<parse>
 yourself, but involves much less parsing work and is shorter and easier to
 implement.
 
-   int (*build1)(pTHX_ OP **out, XSParseKeywordPiece arg0, void *hookdata);
+   int (*build1)(pTHX_ OP **out, XSParseKeywordPiece *arg0, void *hookdata);
 
 If neither C<parse> nor C<build> are present, this is called as a simpler
 variant of C<build> when only a single argument is required. It takes its type
@@ -180,8 +180,8 @@ function, using a C<struct> type consisting of the following fields:
       int line;
    } XSParseKeywordPiece;
 
-Which field of the anonymous is set depends on the type of the piece. The
-I<line> field contains the line number of the source file where parsing of
+Which field of the anonymous union is set depends on the type of the piece.
+The I<line> field contains the line number of the source file where parsing of
 that piece began.
 
 Some piece types are "atomic", whose definition is self-contained. Others are
